You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@calcite.apache.org by jh...@apache.org on 2014/08/25 20:42:26 UTC

[1/8] git commit: HOWTO: instructions for making and verifying a release

Repository: incubator-optiq
Updated Branches:
  refs/heads/master b9928a931 -> c4b0c7b3d


HOWTO: instructions for making and verifying a release


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/1a35667e
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/1a35667e
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/1a35667e

Branch: refs/heads/master
Commit: 1a35667ed5811d3129bda89b0730d2cad920cd3b
Parents: b9928a9
Author: Julian Hyde <jh...@apache.org>
Authored: Fri Aug 22 00:11:49 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 00:11:49 2014 -0700

----------------------------------------------------------------------
 doc/HOWTO.md | 43 +++++++++++++++++++++++++++++++++++++++++--
 1 file changed, 41 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/1a35667e/doc/HOWTO.md
----------------------------------------------------------------------
diff --git a/doc/HOWTO.md b/doc/HOWTO.md
index 0c250ce..3b30bad 100644
--- a/doc/HOWTO.md
+++ b/doc/HOWTO.md
@@ -316,10 +316,10 @@ read GPG_PASSPHRASE
 git clean -xn
 
 # Set the version numbers
-mvn -DskipTests -DreleaseVersion=x.y.z-incubating -DdevelopmentVersion=x.y.z+1-incubating-SNAPSHOT -Papache-release,release -Darguments="-Dgpg.passphrase=${GPG_PASSPHRASE}" clean release:prepare
+mvn -DskipTests -DreleaseVersion=x.y.z-incubating -DdevelopmentVersion=x.y.z+1-incubating-SNAPSHOT -Papache-release -Darguments="-Dgpg.passphrase=${GPG_PASSPHRASE}" clean release:prepare 2>&1 | tee /tmp/prepare.log
 
 # Perform the release
-mvn -DskipTests -Papache-release,release -Darguments="-Dgpg.passphrase=${GPG_PASSPHRASE}" clean release:prepare
+mvn -DskipTests -Papache-release -Darguments="-Dgpg.passphrase=${GPG_PASSPHRASE}" clean release:prepare 2>&1 | tee /tmp/perform.log
 
 ```
 
@@ -377,4 +377,43 @@ git reset --hard HEAD
 ```bash
 # Check that the signing key (e.g. 2AD3FAE3) is pushed
 gpg --recv-keys key
+
+# Check keys
+curl http://people.apache.org/keys/group/optiq.asc > KEYS
+
+# Check keys
+curl -O https://dist.apache.org/repos/dist/release/incubator/optiq/KEYS
+
+# Sign/check md5 and sha1 hashes
+# (Assumes your O/S has 'md5' and 'sha1' commands.)
+function checkHash() {
+  cd "$1"
+  for i in *.{zip,pom,gz}; do
+    if [ ! -f $i ]; then
+      continue
+    fi
+    if [ -f $i.md5 ]; then
+      if [ "$(cat $i.md5)" = "$(md5 -q $i)" ]; then
+        echo $i.md5 present and correct
+      else
+        echo $i.md5 does not match
+      fi
+    else
+      md5 -q $i > $i.md5
+      echo $i.md5 created
+    fi
+    if [ -f $i.sha1 ]; then
+      if [ "$(cat $i.sha1)" = "$(sha1 -q $i)" ]; then
+        echo $i.sha1 present and correct
+      else
+        echo $i.sha1 does not match
+      fi
+    else
+      sha1 -q $i > $i.sha1
+      echo $i.sha1 created
+    fi
+  done
+}
+checkHash optiq-x.y.z-incubating
+
 ```


[4/8] git commit: [OPTIQ-383] Each jar should have a git.properties describing its exact version

Posted by jh...@apache.org.
[OPTIQ-383] Each jar should have a git.properties describing its exact version


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/3580ed4d
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/3580ed4d
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/3580ed4d

Branch: refs/heads/master
Commit: 3580ed4d45f832fb241146075881c99f70e361b8
Parents: 55fbf04
Author: Julian Hyde <jh...@apache.org>
Authored: Thu Aug 21 17:15:03 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 00:24:45 2014 -0700

----------------------------------------------------------------------
 core/pom.xml |   8 ----
 pom.xml      | 114 +++++++++++++++++++++++++++++++++---------------------
 2 files changed, 69 insertions(+), 53 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/3580ed4d/core/pom.xml
----------------------------------------------------------------------
diff --git a/core/pom.xml b/core/pom.xml
index 9bd6020..93ca43d 100644
--- a/core/pom.xml
+++ b/core/pom.xml
@@ -143,14 +143,6 @@ limitations under the License.
 
     <resources>
       <resource>
-        <directory>${top.dir}</directory>
-        <targetPath>META-INF</targetPath>
-        <includes>
-          <include>LICENSE</include>
-          <include>NOTICE</include>
-        </includes>
-      </resource>
-      <resource>
         <directory>src/main/resources</directory>
         <excludes>
           <exclude>version/*.properties</exclude>

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/3580ed4d/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 0268d46..82f76bf 100644
--- a/pom.xml
+++ b/pom.xml
@@ -79,9 +79,6 @@ limitations under the License.
       <groupId>commons-dbcp</groupId>
       <artifactId>commons-dbcp</artifactId>
       <version>1.4</version>
-<!--
-      <scope>test</scope>
--->
     </dependency>
     <dependency>
       <groupId>com.fasterxml.jackson.core</groupId>
@@ -289,6 +286,69 @@ limitations under the License.
           </dependency>
         </dependencies>
       </plugin>
+      <plugin>
+        <groupId>org.codehaus.mojo</groupId>
+        <artifactId>build-helper-maven-plugin</artifactId>
+        <!-- Make sure every sub-project has LICENSE, NOTICE and
+             git.properties in its jar's META-INF directory. -->
+        <executions>
+          <execution>
+            <id>add-resource</id>
+            <phase>generate-resources</phase>
+            <goals>
+              <goal>add-resource</goal>
+              <goal>add-test-resource</goal>
+            </goals>
+            <configuration>
+              <resources>
+                <resource>
+                  <directory>${top.dir}</directory>
+                  <targetPath>META-INF</targetPath>
+                  <includes>
+                    <include>LICENSE</include>
+                    <include>NOTICE</include>
+                  </includes>
+                </resource>
+                <resource>
+                  <directory>${top.dir}/target</directory>
+                  <targetPath>META-INF</targetPath>
+                  <includes>
+                    <include>git.properties</include>
+                  </includes>
+                </resource>
+              </resources>
+            </configuration>
+          </execution>
+        </executions>
+      </plugin>
+      <plugin>
+        <groupId>pl.project13.maven</groupId>
+        <artifactId>git-commit-id-plugin</artifactId>
+        <version>2.1.9</version>
+        <inherited>false</inherited>
+        <executions>
+          <execution>
+            <goals>
+              <goal>revision</goal>
+            </goals>
+          </execution>
+        </executions>
+        <configuration>
+          <dateFormat>yyyy-MM-dd'T'HH:mm:ssZ</dateFormat>
+          <verbose>false</verbose>
+          <skipPoms>false</skipPoms>
+          <generateGitPropertiesFile>true</generateGitPropertiesFile>
+          <generateGitPropertiesFilename>target/git.properties</generateGitPropertiesFilename>
+          <failOnNoGitDirectory>false</failOnNoGitDirectory>
+          <gitDescribe>
+            <skip>false</skip>
+            <always>false</always>
+            <abbrev>7</abbrev>
+            <dirty>-dirty</dirty>
+            <forceLongFormat>true</forceLongFormat>
+          </gitDescribe>
+        </configuration>
+      </plugin>
     </plugins>
 
     <pluginManagement>
@@ -311,22 +371,16 @@ limitations under the License.
         </plugin>
         <plugin>
           <groupId>org.codehaus.mojo</groupId>
+          <artifactId>build-helper-maven-plugin</artifactId>
+          <version>1.9</version>
+        </plugin>
+        <plugin>
+          <groupId>org.codehaus.mojo</groupId>
           <artifactId>javacc-maven-plugin</artifactId>
           <version>2.4</version>
         </plugin>
       </plugins>
     </pluginManagement>
-
-    <resources>
-      <resource>
-        <directory>${top.dir}</directory>
-        <targetPath>META-INF</targetPath>
-        <includes>
-          <include>LICENSE</include>
-          <include>NOTICE</include>
-        </includes>
-      </resource>
-    </resources>
   </build>
 
   <reporting>
@@ -403,38 +457,9 @@ limitations under the License.
 
   <profiles>
     <profile>
-      <id>release</id>
+      <id>apache-release</id>
       <build>
         <plugins>
-          <plugin>
-            <groupId>pl.project13.maven</groupId>
-            <artifactId>git-commit-id-plugin</artifactId>
-            <version>2.1.9</version>
-            <inherited>false</inherited>
-            <executions>
-              <execution>
-                <goals>
-                  <goal>revision</goal>
-                </goals>
-              </execution>
-            </executions>
-            <configuration>
-              <dateFormat>yyyy-MM-dd'T'HH:mm:ssZ</dateFormat>
-              <verbose>false</verbose>
-              <skipPoms>false</skipPoms>
-              <generateGitPropertiesFile>true</generateGitPropertiesFile>
-              <generateGitPropertiesFilename>./git.properties</generateGitPropertiesFilename>
-              <failOnNoGitDirectory>false</failOnNoGitDirectory>
-              <gitDescribe>
-                <skip>false</skip>
-                <always>false</always>
-                <abbrev>7</abbrev>
-                <dirty>-dirty</dirty>
-                <forceLongFormat>true</forceLongFormat>
-              </gitDescribe>
-            </configuration>
-          </plugin>
-
           <!-- Apache-RAT checks for files without headers.
                If run on a messy developer's sandbox, it will fail.
                This serves as a reminder to only build a release in a clean
@@ -446,7 +471,6 @@ limitations under the License.
               <excludes>
                 <exclude>*.md</exclude>
                 <exclude>doc/*.md</exclude>
-                <exclude>git.properties</exclude>
                 <exclude>src/main/resources/META-INF/services/java.sql.Driver</exclude>
               </excludes>
             </configuration>


[2/8] git commit: Status icon based on master branch, not whichever branch happened to build most recently.

Posted by jh...@apache.org.
Status icon based on master branch, not whichever branch happened to build most recently.


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/0d84e622
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/0d84e622
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/0d84e622

Branch: refs/heads/master
Commit: 0d84e622facf80cc3d2d0bb01b16fac3bec3bd6e
Parents: 1a35667
Author: Julian Hyde <jh...@apache.org>
Authored: Tue Aug 19 12:52:14 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 00:15:23 2014 -0700

----------------------------------------------------------------------
 README.md | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/0d84e622/README.md
----------------------------------------------------------------------
diff --git a/README.md b/README.md
index 7adaa5a..cd5f7b8 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-[![Build Status](https://travis-ci.org/julianhyde/optiq.png)](https://travis-ci.org/julianhyde/optiq)
+[![Build Status](https://travis-ci.org/julianhyde/optiq.svg?branch=master)](https://travis-ci.org/julianhyde/optiq)
 
 # Apache Optiq
 


[6/8] git commit: [OPTIQ-382] Refactoring rules to use factories

Posted by jh...@apache.org.
[OPTIQ-382] Refactoring rules to use factories


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/48bcaddc
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/48bcaddc
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/48bcaddc

Branch: refs/heads/master
Commit: 48bcaddc9a3bf4b5a34a430e927a90efba62b8f6
Parents: 5836698
Author: John Pullokkaran <jp...@hortonworks.com>
Authored: Wed Aug 20 17:50:54 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 00:55:36 2014 -0700

----------------------------------------------------------------------
 .../eigenbase/rel/rules/MergeFilterRule.java    | 24 ++++++++++---------
 .../eigenbase/rel/rules/MergeProjectRule.java   |  8 +++----
 .../rel/rules/PushFilterPastJoinRule.java       | 25 +++++++++++++-------
 .../rel/rules/PushFilterPastSetOpRule.java      |  2 +-
 .../rel/rules/RemoveTrivialProjectRule.java     |  8 +++----
 .../java/org/eigenbase/relopt/RelOptUtil.java   | 24 +++++++++++++++++--
 6 files changed, 61 insertions(+), 30 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/48bcaddc/core/src/main/java/org/eigenbase/rel/rules/MergeFilterRule.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/eigenbase/rel/rules/MergeFilterRule.java b/core/src/main/java/org/eigenbase/rel/rules/MergeFilterRule.java
index 5725bd5..51cabd0 100644
--- a/core/src/main/java/org/eigenbase/rel/rules/MergeFilterRule.java
+++ b/core/src/main/java/org/eigenbase/rel/rules/MergeFilterRule.java
@@ -24,26 +24,29 @@ import org.eigenbase.rex.*;
  * MergeFilterRule implements the rule for combining two {@link FilterRel}s
  */
 public class MergeFilterRule extends RelOptRule {
-  public static final MergeFilterRule INSTANCE = new MergeFilterRule();
+  public static final MergeFilterRule INSTANCE =
+      new MergeFilterRule(RelFactories.DEFAULT_FILTER_FACTORY);
+
+  private final RelFactories.FilterFactory filterFactory;
 
   //~ Constructors -----------------------------------------------------------
 
   /**
    * Creates a MergeFilterRule.
    */
-  private MergeFilterRule() {
+  public MergeFilterRule(RelFactories.FilterFactory filterFactory) {
     super(
-        operand(
-            FilterRel.class,
-            operand(FilterRel.class, any())));
+        operand(FilterRelBase.class,
+            operand(FilterRelBase.class, any())));
+    this.filterFactory = filterFactory;
   }
 
   //~ Methods ----------------------------------------------------------------
 
   // implement RelOptRule
   public void onMatch(RelOptRuleCall call) {
-    FilterRel topFilter = call.rel(0);
-    FilterRel bottomFilter = call.rel(1);
+    final FilterRelBase topFilter = call.rel(0);
+    final FilterRelBase bottomFilter = call.rel(1);
 
     // use RexPrograms to merge the two FilterRels into a single program
     // so we can convert the two FilterRel conditions to directly
@@ -62,9 +65,8 @@ public class MergeFilterRule extends RelOptRule {
         mergedProgram.expandLocalRef(
             mergedProgram.getCondition());
 
-    FilterRel newFilterRel =
-        new FilterRel(
-            topFilter.getCluster(),
+    FilterRelBase newFilterRel =
+        (FilterRelBase) filterFactory.createFilter(
             bottomFilter.getChild(),
             newCondition);
 
@@ -77,7 +79,7 @@ public class MergeFilterRule extends RelOptRule {
    * @param filterRel the FilterRel
    * @return created RexProgram
    */
-  private RexProgram createProgram(FilterRel filterRel) {
+  private RexProgram createProgram(FilterRelBase filterRel) {
     RexProgramBuilder programBuilder =
         new RexProgramBuilder(
             filterRel.getRowType(),

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/48bcaddc/core/src/main/java/org/eigenbase/rel/rules/MergeProjectRule.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/eigenbase/rel/rules/MergeProjectRule.java b/core/src/main/java/org/eigenbase/rel/rules/MergeProjectRule.java
index 2a616f0..d802171 100644
--- a/core/src/main/java/org/eigenbase/rel/rules/MergeProjectRule.java
+++ b/core/src/main/java/org/eigenbase/rel/rules/MergeProjectRule.java
@@ -24,7 +24,8 @@ import org.eigenbase.relopt.*;
 import org.eigenbase.rex.*;
 
 /**
- * MergeProjectRule merges a {@link ProjectRelBase} into another {@link ProjectRelBase},
+ * MergeProjectRule merges a {@link ProjectRelBase} into
+ * another {@link ProjectRelBase},
  * provided the projects aren't projecting identical sets of input references.
  */
 public class MergeProjectRule extends RelOptRule {
@@ -56,9 +57,8 @@ public class MergeProjectRule extends RelOptRule {
    */
   public MergeProjectRule(boolean force, ProjectFactory pFactory) {
     super(
-        operand(
-            ProjectRel.class,
-            operand(ProjectRel.class, any())),
+        operand(ProjectRelBase.class,
+            operand(ProjectRelBase.class, any())),
         "MergeProjectRule" + (force ? ": force mode" : ""));
     this.force = force;
     projectFactory = pFactory;

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/48bcaddc/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastJoinRule.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastJoinRule.java b/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastJoinRule.java
index 7ecbd5b..69af944 100644
--- a/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastJoinRule.java
+++ b/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastJoinRule.java
@@ -40,13 +40,16 @@ public abstract class PushFilterPastJoinRule extends RelOptRule {
       new PushFilterIntoJoinRule(false);
 
   public static final PushFilterPastJoinRule JOIN =
-      new PushDownJoinConditionRule(RelFactories.DEFAULT_FILTER_FACTORY);
+      new PushDownJoinConditionRule(RelFactories.DEFAULT_FILTER_FACTORY,
+          RelFactories.DEFAULT_PROJECT_FACTORY);
 
   /** Whether to try to strengthen join-type. */
   private final boolean smart;
 
   private final RelFactories.FilterFactory filterFactory;
 
+  private final RelFactories.ProjectFactory projectFactory;
+
   //~ Constructors -----------------------------------------------------------
 
   /**
@@ -54,10 +57,12 @@ public abstract class PushFilterPastJoinRule extends RelOptRule {
    * factories.
    */
   protected PushFilterPastJoinRule(RelOptRuleOperand operand, String id,
-      boolean smart, RelFactories.FilterFactory filterFactory) {
+      boolean smart, RelFactories.FilterFactory filterFactory,
+      RelFactories.ProjectFactory projectFactory) {
     super(operand, "PushFilterRule: " + id);
     this.smart = smart;
     this.filterFactory = filterFactory;
+    this.projectFactory = projectFactory;
   }
 
   //~ Methods ----------------------------------------------------------------
@@ -188,7 +193,8 @@ public abstract class PushFilterPastJoinRule extends RelOptRule {
 
     // Create a project on top of the join if some of the columns have become
     // NOT NULL due to the join-type getting stricter.
-    newJoinRel = RelOptUtil.createCastRel(newJoinRel, join.getRowType(), false);
+    newJoinRel = RelOptUtil.createCastRel(newJoinRel, join.getRowType(),
+        false, projectFactory);
 
     // create a FilterRel on top of the join if needed
     RelNode newRel =
@@ -221,10 +227,11 @@ public abstract class PushFilterPastJoinRule extends RelOptRule {
   /** Rule that pushes parts of the join condition to its inputs. */
   public static class PushDownJoinConditionRule
       extends PushFilterPastJoinRule {
-    public PushDownJoinConditionRule(RelFactories.FilterFactory filterFactory) {
+    public PushDownJoinConditionRule(RelFactories.FilterFactory filterFactory,
+        RelFactories.ProjectFactory projectFactory) {
       super(RelOptRule.operand(JoinRelBase.class, RelOptRule.any()),
           "PushFilterPastJoinRule:no-filter",
-          true, filterFactory);
+          true, filterFactory, projectFactory);
     }
 
     @Override
@@ -238,16 +245,18 @@ public abstract class PushFilterPastJoinRule extends RelOptRule {
    * condition and into the inputs of the join. */
   public static class PushFilterIntoJoinRule extends PushFilterPastJoinRule {
     public PushFilterIntoJoinRule(boolean smart) {
-      this(smart, RelFactories.DEFAULT_FILTER_FACTORY);
+      this(smart, RelFactories.DEFAULT_FILTER_FACTORY,
+          RelFactories.DEFAULT_PROJECT_FACTORY);
     }
 
     public PushFilterIntoJoinRule(boolean smart,
-        RelFactories.FilterFactory filterFactory) {
+        RelFactories.FilterFactory filterFactory,
+        RelFactories.ProjectFactory projectFactory) {
       super(
           RelOptRule.operand(FilterRelBase.class,
               RelOptRule.operand(JoinRelBase.class, RelOptRule.any())),
           "PushFilterPastJoinRule:filter",
-          smart, filterFactory);
+          smart, filterFactory, projectFactory);
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/48bcaddc/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastSetOpRule.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastSetOpRule.java b/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastSetOpRule.java
index 6743a3c..14b93cb 100644
--- a/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastSetOpRule.java
+++ b/core/src/main/java/org/eigenbase/rel/rules/PushFilterPastSetOpRule.java
@@ -39,7 +39,7 @@ public class PushFilterPastSetOpRule extends RelOptRule {
   /**
    * Creates a PushFilterPastSetOpRule.
    */
-  private PushFilterPastSetOpRule(RelFactories.FilterFactory filterFactory) {
+  public PushFilterPastSetOpRule(RelFactories.FilterFactory filterFactory) {
     super(
         operand(FilterRelBase.class,
             operand(SetOpRel.class, any())));

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/48bcaddc/core/src/main/java/org/eigenbase/rel/rules/RemoveTrivialProjectRule.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/eigenbase/relopt/RelOptUtil.java b/core/src/main/java/org/eigenbase/relopt/RelOptUtil.java
index 2593966..52ddd18 100644
--- a/core/src/main/java/org/eigenbase/relopt/RelOptUtil.java
+++ b/core/src/main/java/org/eigenbase/relopt/RelOptUtil.java
@@ -496,6 +496,26 @@ public abstract class RelOptUtil {
       final RelNode rel,
       RelDataType castRowType,
       boolean rename) {
+    return createCastRel(rel, castRowType, rename,
+        RelFactories.DEFAULT_PROJECT_FACTORY);
+  }
+
+  /**
+   * Creates a projection which casts a rel's output to a desired row type.
+   *
+   * @param rel         producer of rows to be converted
+   * @param castRowType row type after cast
+   * @param rename      if true, use field names from castRowType; if false,
+   *                    preserve field names from rel
+   * @param projectFactory Project Factory
+   * @return conversion rel
+   */
+  public static RelNode createCastRel(
+      final RelNode rel,
+      RelDataType castRowType,
+      boolean rename,
+      RelFactories.ProjectFactory projectFactory) {
+    assert projectFactory != null;
     RelDataType rowType = rel.getRowType();
     if (areRowTypesEqual(rowType, castRowType, rename)) {
       // nothing to do
@@ -506,13 +526,13 @@ public abstract class RelOptUtil {
             rel.getCluster().getRexBuilder(), castRowType, rowType);
     if (rename) {
       // Use names and types from castRowType.
-      return CalcRel.createProject(
+      return projectFactory.createProject(
           rel,
           castExps,
           castRowType.getFieldNames());
     } else {
       // Use names from rowType, types from castRowType.
-      return CalcRel.createProject(
+      return projectFactory.createProject(
           rel,
           castExps,
           rowType.getFieldNames());


[5/8] git commit: [OPTIQ-381] Remove plugin versions from the tag in root pom

Posted by jh...@apache.org.
[OPTIQ-381] Remove plugin versions from the <plugins> tag in root pom

Also, remove Pentaho from repositories list.


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/58366980
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/58366980
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/58366980

Branch: refs/heads/master
Commit: 58366980450ccd3579b2cf85659ad99312351641
Parents: 3580ed4
Author: Julian Hyde <jh...@apache.org>
Authored: Thu Aug 21 17:50:05 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 00:41:10 2014 -0700

----------------------------------------------------------------------
 pom.xml | 28 +++++++++++++++-------------
 1 file changed, 15 insertions(+), 13 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/58366980/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 82f76bf..cd2f019 100644
--- a/pom.xml
+++ b/pom.xml
@@ -248,6 +248,7 @@ limitations under the License.
         </executions>
       </plugin>
       <plugin>
+        <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-compiler-plugin</artifactId>
         <configuration>
           <source>1.5</source>
@@ -257,7 +258,6 @@ limitations under the License.
       <plugin>
         <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-checkstyle-plugin</artifactId>
-        <version>2.12.1</version>
         <executions>
           <execution>
             <id>validate</id>
@@ -277,6 +277,10 @@ limitations under the License.
         </executions>
       </plugin>
       <plugin>
+        <!-- Override apache parent POM's definition of release
+             plugin. If we don't specify gitexe version, git doesn't
+             commit during release process. -->
+        <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-release-plugin</artifactId>
         <dependencies>
           <dependency>
@@ -324,7 +328,6 @@ limitations under the License.
       <plugin>
         <groupId>pl.project13.maven</groupId>
         <artifactId>git-commit-id-plugin</artifactId>
-        <version>2.1.9</version>
         <inherited>false</inherited>
         <executions>
           <execution>
@@ -366,6 +369,11 @@ limitations under the License.
         </plugin>
         <plugin>
           <groupId>org.apache.maven.plugins</groupId>
+          <artifactId>maven-checkstyle-plugin</artifactId>
+          <version>2.12.1</version>
+        </plugin>
+        <plugin>
+          <groupId>org.apache.maven.plugins</groupId>
           <artifactId>maven-shade-plugin</artifactId>
           <version>2.1</version>
         </plugin>
@@ -379,6 +387,11 @@ limitations under the License.
           <artifactId>javacc-maven-plugin</artifactId>
           <version>2.4</version>
         </plugin>
+        <plugin>
+          <groupId>pl.project13.maven</groupId>
+          <artifactId>git-commit-id-plugin</artifactId>
+          <version>2.1.9</version>
+        </plugin>
       </plugins>
     </pluginManagement>
   </build>
@@ -423,17 +436,6 @@ limitations under the License.
         <updatePolicy>always</updatePolicy>
         <checksumPolicy>warn</checksumPolicy>
       </releases>
-      <id>pentaho</id>
-      <name>Pentaho</name>
-      <url>http://repo.pentaho.org/artifactory/repo</url>
-      <layout>default</layout>
-    </repository>
-    <repository>
-      <releases>
-        <enabled>true</enabled>
-        <updatePolicy>always</updatePolicy>
-        <checksumPolicy>warn</checksumPolicy>
-      </releases>
       <id>conjars</id>
       <name>Conjars</name>
       <url>http://conjars.org/repo</url>


[7/8] git commit: Fix git-commit-id-plugin error when running in Travis-CI.

Posted by jh...@apache.org.
Fix git-commit-id-plugin error when running in Travis-CI.


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/bb3e55c5
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/bb3e55c5
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/bb3e55c5

Branch: refs/heads/master
Commit: bb3e55c5a910a6d447a9b60bab0de975b6017f2b
Parents: 48bcadd
Author: Julian Hyde <jh...@apache.org>
Authored: Fri Aug 22 01:26:23 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 01:26:23 2014 -0700

----------------------------------------------------------------------
 .travis.yml | 2 ++
 1 file changed, 2 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/bb3e55c5/.travis.yml
----------------------------------------------------------------------
diff --git a/.travis.yml b/.travis.yml
index 720e293..5b8e0d5 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -27,4 +27,6 @@ branches:
     - javadoc
 script:
   mvn test site
+git:
+  depth: 10000
 # End .travis.yml


[3/8] git commit: Fix 'mvn site' on JDK 1.8 and enable in Travis-CI.

Posted by jh...@apache.org.
Fix 'mvn site' on JDK 1.8 and enable in Travis-CI.

Fix several javadoc errors and warnings.

Remove some duplicate package-info.java files.

Remove versions of maven plugins where apache pom already specifies a version.


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/55fbf047
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/55fbf047
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/55fbf047

Branch: refs/heads/master
Commit: 55fbf047681affa637825c3108df1d1a80855063
Parents: 0d84e62
Author: Julian Hyde <jh...@apache.org>
Authored: Tue Aug 19 12:28:55 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 00:15:23 2014 -0700

----------------------------------------------------------------------
 .travis.yml                                     |  4 ++-
 .../hydromatic/avatica/AvaticaConnection.java   |  1 +
 .../net/hydromatic/avatica/AvaticaFactory.java  |  1 +
 .../avatica/AvaticaPreparedStatement.java       |  3 ++
 .../java/net/hydromatic/avatica/Cursor.java     |  5 ++-
 .../avatica/test/ConnectStringParserTest.java   |  2 --
 .../eigenbase/rel/metadata/RelMdPredicates.java | 17 ++++++-----
 .../java/org/eigenbase/test/DiffRepository.java |  3 +-
 .../org/eigenbase/test/SqlToRelTestBase.java    |  1 +
 .../eigenbase/test/concurrent/package-info.java | 11 +++----
 .../net/hydromatic/optiq/test/package-info.java | 23 --------------
 pom.xml                                         | 32 +-------------------
 .../net/hydromatic/optiq/test/package-info.java | 23 --------------
 .../optiq/impl/splunk/search/package-info.java  |  4 +--
 .../optiq/impl/splunk/util/package-info.java    |  4 +--
 .../net/hydromatic/optiq/test/package-info.java | 23 --------------
 src/main/config/checkstyle/suppressions.xml     |  3 ++
 .../net/hydromatic/optiq/StatementTest.java     | 16 ++++++++++
 .../java/net/hydromatic/optiq/package-info.java | 25 ---------------
 19 files changed, 53 insertions(+), 148 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/.travis.yml
----------------------------------------------------------------------
diff --git a/.travis.yml b/.travis.yml
index caceb4e..720e293 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -24,5 +24,7 @@ jdk:
 branches:
   only:
     - master
-
+    - javadoc
+script:
+  mvn test site
 # End .travis.yml

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/avatica/src/main/java/net/hydromatic/avatica/AvaticaConnection.java
----------------------------------------------------------------------
diff --git a/avatica/src/main/java/net/hydromatic/avatica/AvaticaConnection.java b/avatica/src/main/java/net/hydromatic/avatica/AvaticaConnection.java
index 9b9994d..c05e89f 100644
--- a/avatica/src/main/java/net/hydromatic/avatica/AvaticaConnection.java
+++ b/avatica/src/main/java/net/hydromatic/avatica/AvaticaConnection.java
@@ -371,6 +371,7 @@ public abstract class AvaticaConnection implements Connection {
   /**
    * Executes a parsed query, closing any previously open result set.
    *
+   * @param statement     Statement
    * @param prepareResult Parsed query
    * @return Result set
    * @throws java.sql.SQLException if a database error occurs

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/avatica/src/main/java/net/hydromatic/avatica/AvaticaFactory.java
----------------------------------------------------------------------
diff --git a/avatica/src/main/java/net/hydromatic/avatica/AvaticaFactory.java b/avatica/src/main/java/net/hydromatic/avatica/AvaticaFactory.java
index e48e968..bdb9c0f 100644
--- a/avatica/src/main/java/net/hydromatic/avatica/AvaticaFactory.java
+++ b/avatica/src/main/java/net/hydromatic/avatica/AvaticaFactory.java
@@ -57,6 +57,7 @@ public interface AvaticaFactory {
    *
    * @param statement Statement
    * @param prepareResult Prepared statement
+   * @param timeZone Time zone
    * @return Result set
    */
   AvaticaResultSet newResultSet(

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/avatica/src/main/java/net/hydromatic/avatica/AvaticaPreparedStatement.java
----------------------------------------------------------------------
diff --git a/avatica/src/main/java/net/hydromatic/avatica/AvaticaPreparedStatement.java b/avatica/src/main/java/net/hydromatic/avatica/AvaticaPreparedStatement.java
index b507b60..04534b8 100644
--- a/avatica/src/main/java/net/hydromatic/avatica/AvaticaPreparedStatement.java
+++ b/avatica/src/main/java/net/hydromatic/avatica/AvaticaPreparedStatement.java
@@ -43,6 +43,9 @@ public abstract class AvaticaPreparedStatement
    *
    * @param connection Connection
    * @param prepareResult Result of preparing statement
+   * @param resultSetType Result set type
+   * @param resultSetConcurrency Result set concurrency
+   * @param resultSetHoldability Result set holdability
    * @throws SQLException If fails due to underlying implementation reasons.
    */
   protected AvaticaPreparedStatement(

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/avatica/src/main/java/net/hydromatic/avatica/Cursor.java
----------------------------------------------------------------------
diff --git a/avatica/src/main/java/net/hydromatic/avatica/Cursor.java b/avatica/src/main/java/net/hydromatic/avatica/Cursor.java
index 1978cc2..f719852 100644
--- a/avatica/src/main/java/net/hydromatic/avatica/Cursor.java
+++ b/avatica/src/main/java/net/hydromatic/avatica/Cursor.java
@@ -45,6 +45,8 @@ public interface Cursor extends Closeable {
    * Moves to the next row.
    *
    * @return Whether moved
+   *
+   * @throws SQLException on database error
    */
   boolean next() throws SQLException;
 
@@ -55,7 +57,8 @@ public interface Cursor extends Closeable {
 
   /**
    * Returns whether the last value returned was null.
-   * @throws SQLException
+   *
+   * @throws SQLException on database error
    */
   boolean wasNull() throws SQLException;
 

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/avatica/src/test/java/net/hydromatic/avatica/test/ConnectStringParserTest.java
----------------------------------------------------------------------
diff --git a/avatica/src/test/java/net/hydromatic/avatica/test/ConnectStringParserTest.java b/avatica/src/test/java/net/hydromatic/avatica/test/ConnectStringParserTest.java
index 2d1d93c..38dd5ee 100644
--- a/avatica/src/test/java/net/hydromatic/avatica/test/ConnectStringParserTest.java
+++ b/avatica/src/test/java/net/hydromatic/avatica/test/ConnectStringParserTest.java
@@ -138,8 +138,6 @@ public class ConnectStringParserTest {
    * href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/oledb/htm/oledbconnectionstringsyntax.asp">
    * OLE DB spec</a>. Omitted are cases for Window handles, returning multiple
    * values, and special handling of "Provider" keyword.
-   *
-   * @throws Throwable
    */
   @Test public void testOleDbExamples() throws Throwable {
     // test the parser with examples from OLE DB documentation

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/core/src/main/java/org/eigenbase/rel/metadata/RelMdPredicates.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/eigenbase/rel/metadata/RelMdPredicates.java b/core/src/main/java/org/eigenbase/rel/metadata/RelMdPredicates.java
index 44490de..eddaeff 100644
--- a/core/src/main/java/org/eigenbase/rel/metadata/RelMdPredicates.java
+++ b/core/src/main/java/org/eigenbase/rel/metadata/RelMdPredicates.java
@@ -79,14 +79,17 @@ import com.google.common.collect.Lists;
  * Grouping Keys. This can be extended to infer predicates on Aggregation
  * expressions from  expressions on the aggregated columns. For e.g.
  * <pre>
- * select a, max(b) from R1 where b > 7 => max(b) > 7 or max(b) is null
+ * select a, max(b) from R1 where b &gt; 7
+ *   &rarr; max(b) &gt; 7 or max(b) is null
  * </pre>
  *
  * <li> For Projections we only look at columns that are projected without
  * any function applied. So:
  * <pre>
- * select a from R1 where a > 7 -> a > 7 is pulledUp from the Projection.
- * select a + 1 from R1 where a + 1 > 7 -> a + 1 > 7 is not pulledUp
+ * select a from R1 where a &gt; 7
+ *   &rarr; "a &gt; 7" is pulled up from the Projection.
+ * select a + 1 from R1 where a + 1 &gt; 7
+ *   &rarr; "a + 1 gt; 7" is not pulled up
  * </pre>
  *
  * <li> There are several restrictions on Joins:
@@ -135,9 +138,9 @@ public class RelMdPredicates {
    * is not in the projection list.
    *
    * <pre>
-   * childPullUpExprs:      {a > 7, b + c < 10, a + e = 9}
+   * childPullUpExprs:      {a &gt; 7, b + c &lt; 10, a + e = 9}
    * projectionExprs:       {a, b, c, e / 2}
-   * projectionPullupExprs: {a > 7, b + c < 10}
+   * projectionPullupExprs: {a &gt; 7, b + c &lt; 10}
    * </pre>
    *
    * </ol>
@@ -213,9 +216,9 @@ public class RelMdPredicates {
    * GroupSet. For e.g.
    *
    * <pre>
-   * childPullUpExprs : { a > 7, b + c < 10, a + e = 9}
+   * childPullUpExprs : { a &gt; 7, b + c &lt; 10, a + e = 9}
    * groupSet         : { a, b}
-   * pulledUpExprs    : { a > 7}
+   * pulledUpExprs    : { a &gt; 7}
    * </pre>
    */
   public RelOptPredicateList getPredicates(AggregateRelBase agg) {

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/core/src/test/java/org/eigenbase/test/DiffRepository.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/eigenbase/test/DiffRepository.java b/core/src/test/java/org/eigenbase/test/DiffRepository.java
index 358482c..97f38e2 100644
--- a/core/src/test/java/org/eigenbase/test/DiffRepository.java
+++ b/core/src/test/java/org/eigenbase/test/DiffRepository.java
@@ -686,7 +686,8 @@ public class DiffRepository {
      * @param testCaseName   Test case name
      * @param tag            Tag being expanded
      * @param text           Text being expanded
-     * @param expanded       Expanded text @return Expanded text after filtering
+     * @param expanded       Expanded text
+     * @return Expanded text after filtering
      */
     String filter(
         DiffRepository diffRepository,

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/core/src/test/java/org/eigenbase/test/SqlToRelTestBase.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/eigenbase/test/SqlToRelTestBase.java b/core/src/test/java/org/eigenbase/test/SqlToRelTestBase.java
index 5c761dc..64d3b6f 100644
--- a/core/src/test/java/org/eigenbase/test/SqlToRelTestBase.java
+++ b/core/src/test/java/org/eigenbase/test/SqlToRelTestBase.java
@@ -147,6 +147,7 @@ public abstract class SqlToRelTestBase {
      *
      * @param sql  SQL query
      * @param plan Expected plan
+     * @param trim Whether to trim columns that are not needed
      */
     void assertConvertsTo(
         String sql,

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/core/src/test/java/org/eigenbase/test/concurrent/package-info.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/eigenbase/test/concurrent/package-info.java b/core/src/test/java/org/eigenbase/test/concurrent/package-info.java
index df06aad..ca78773 100644
--- a/core/src/test/java/org/eigenbase/test/concurrent/package-info.java
+++ b/core/src/test/java/org/eigenbase/test/concurrent/package-info.java
@@ -40,7 +40,7 @@
  * <p>
  *     The syntactic structure of an <i>mtsql</i> script is:
  *
- * <p><pre>
+ * <pre>
  *     &lt;directive&gt;*
  *     &lt;setup section&gt;?
  *     &lt;cleanup section&gt;?
@@ -74,8 +74,6 @@
  *     Next all the thread sections are run at once, each in its own thread.
  *     When all these threads complete, the cleanup section (if any) is run.
  *
- * <p>
- *
  * <h4>Synchronization:</h4>
  *
  * <p>The threads are synchronized by inserting synchronization points
@@ -112,11 +110,11 @@
  *
  * <h4>Basic Commands (allowed in any section):</h4>
  *
- * <p><pre>
+ * <pre>
  * &lt;SQL statement&gt;:
  *     An SQL statement terminated by a semicolon. The statement can span lines.
  * </pre>
- * <p><pre>
+ * <pre>
  * &#64;include FILE
  *   Reads and executes the contents of FILE, another mtsql script.
  *   Inclusions may nest.
@@ -124,7 +122,7 @@
  *
  * <h4>Threaded Commands (allowed only in a &#64;thread section):</h4>
  *
- * <p><pre>
+ * <pre>
  * &#64;sleep N        -- thread sleeps for N milliseconds
  * &#64;echo MESSAGE   -- prints the message to stdout
  *
@@ -176,7 +174,6 @@
  *     useful to
  *     parameterize SQL statements, timeout values etc.
  *
- * <p>
  * <ul>
  *     <li>Variable Expansion: If VAR is a declared variable, $VAR is replaced
  *         by the value of VAR. Quotes are ignored.  $$ expands to $. A variable

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/mongodb/src/test/java/net/hydromatic/optiq/test/package-info.java
----------------------------------------------------------------------
diff --git a/mongodb/src/test/java/net/hydromatic/optiq/test/package-info.java b/mongodb/src/test/java/net/hydromatic/optiq/test/package-info.java
deleted file mode 100644
index 90df564..0000000
--- a/mongodb/src/test/java/net/hydromatic/optiq/test/package-info.java
+++ /dev/null
@@ -1,23 +0,0 @@
-/*
-// Licensed to the Apache Software Foundation (ASF) under one or more
-// contributor license agreements.  See the NOTICE file distributed with
-// this work for additional information regarding copyright ownership.
-// The ASF licenses this file to you under the Apache License, Version 2.0
-// (the "License"); you may not use this file except in compliance with
-// the License.  You may obtain a copy of the License at
-//
-// http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-*/
-
-/**
- * Provides utility classes.
- */
-package org.eigenbase.util;
-
-// End package-info.java

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 1416efb..0268d46 100644
--- a/pom.xml
+++ b/pom.xml
@@ -239,7 +239,6 @@ limitations under the License.
       <plugin>
         <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-source-plugin</artifactId>
-        <version>2.2.1</version>
         <executions>
           <execution>
             <id>attach-sources</id>
@@ -253,7 +252,6 @@ limitations under the License.
       </plugin>
       <plugin>
         <artifactId>maven-compiler-plugin</artifactId>
-        <version>2.3.2</version>
         <configuration>
           <source>1.5</source>
           <target>1.5</target>
@@ -283,7 +281,6 @@ limitations under the License.
       </plugin>
       <plugin>
         <artifactId>maven-release-plugin</artifactId>
-        <version>2.4.2</version>
         <dependencies>
           <dependency>
             <groupId>org.apache.maven.scm</groupId>
@@ -309,33 +306,8 @@ limitations under the License.
         </plugin>
         <plugin>
           <groupId>org.apache.maven.plugins</groupId>
-          <artifactId>maven-compiler-plugin</artifactId>
-          <version>2.3.2</version>
-        </plugin>
-        <plugin>
-          <groupId>org.apache.maven.plugins</groupId>
-          <artifactId>maven-jar-plugin</artifactId>
-          <version>2.2</version>
-        </plugin>
-        <plugin>
-          <groupId>org.apache.maven.plugins</groupId>
-          <artifactId>maven-release-plugin</artifactId>
-          <version>2.4.1</version>
-        </plugin>
-        <plugin>
-          <groupId>org.apache.maven.plugins</groupId>
           <artifactId>maven-shade-plugin</artifactId>
-          <version>2.0</version>
-        </plugin>
-        <plugin>
-          <groupId>org.apache.maven.plugins</groupId>
-          <artifactId>maven-source-plugin</artifactId>
-          <version>2.2.1</version>
-        </plugin>
-        <plugin>
-          <groupId>org.apache.maven.plugins</groupId>
-          <artifactId>maven-surefire-plugin</artifactId>
-          <version>2.16</version>
+          <version>2.1</version>
         </plugin>
         <plugin>
           <groupId>org.codehaus.mojo</groupId>
@@ -362,7 +334,6 @@ limitations under the License.
       <plugin>
         <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-javadoc-plugin</artifactId>
-        <version>2.8.1</version>
         <configuration>
           <links>
             <link>http://docs.oracle.com/javase/8/docs/api/</link>
@@ -471,7 +442,6 @@ limitations under the License.
           <plugin>
             <groupId>org.apache.rat</groupId>
             <artifactId>apache-rat-plugin</artifactId>
-            <version>0.10</version>
             <configuration>
               <excludes>
                 <exclude>*.md</exclude>

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/spark/src/test/java/net/hydromatic/optiq/test/package-info.java
----------------------------------------------------------------------
diff --git a/spark/src/test/java/net/hydromatic/optiq/test/package-info.java b/spark/src/test/java/net/hydromatic/optiq/test/package-info.java
deleted file mode 100644
index efa92d2..0000000
--- a/spark/src/test/java/net/hydromatic/optiq/test/package-info.java
+++ /dev/null
@@ -1,23 +0,0 @@
-/*
-// Licensed to the Apache Software Foundation (ASF) under one or more
-// contributor license agreements.  See the NOTICE file distributed with
-// this work for additional information regarding copyright ownership.
-// The ASF licenses this file to you under the Apache License, Version 2.0
-// (the "License"); you may not use this file except in compliance with
-// the License.  You may obtain a copy of the License at
-//
-// http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-*/
-
-/**
- * Unit tests for Optiq.
- */
-package net.hydromatic.optiq.test;
-
-// End package-info.java

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/search/package-info.java
----------------------------------------------------------------------
diff --git a/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/search/package-info.java b/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/search/package-info.java
index 90df564..cb2b178 100644
--- a/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/search/package-info.java
+++ b/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/search/package-info.java
@@ -16,8 +16,8 @@
 */
 
 /**
- * Provides utility classes.
+ * Executes queries via Splunk's REST API.
  */
-package org.eigenbase.util;
+package net.hydromatic.optiq.impl.splunk.search;
 
 // End package-info.java

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/util/package-info.java
----------------------------------------------------------------------
diff --git a/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/util/package-info.java b/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/util/package-info.java
index 90df564..41e9ed4 100644
--- a/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/util/package-info.java
+++ b/splunk/src/main/java/net/hydromatic/optiq/impl/splunk/util/package-info.java
@@ -16,8 +16,8 @@
 */
 
 /**
- * Provides utility classes.
+ * Utilities for RPC to Splunk.
  */
-package org.eigenbase.util;
+package net.hydromatic.optiq.impl.splunk.util;
 
 // End package-info.java

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/splunk/src/test/java/net/hydromatic/optiq/test/package-info.java
----------------------------------------------------------------------
diff --git a/splunk/src/test/java/net/hydromatic/optiq/test/package-info.java b/splunk/src/test/java/net/hydromatic/optiq/test/package-info.java
deleted file mode 100644
index 90df564..0000000
--- a/splunk/src/test/java/net/hydromatic/optiq/test/package-info.java
+++ /dev/null
@@ -1,23 +0,0 @@
-/*
-// Licensed to the Apache Software Foundation (ASF) under one or more
-// contributor license agreements.  See the NOTICE file distributed with
-// this work for additional information regarding copyright ownership.
-// The ASF licenses this file to you under the Apache License, Version 2.0
-// (the "License"); you may not use this file except in compliance with
-// the License.  You may obtain a copy of the License at
-//
-// http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-*/
-
-/**
- * Provides utility classes.
- */
-package org.eigenbase.util;
-
-// End package-info.java

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/src/main/config/checkstyle/suppressions.xml
----------------------------------------------------------------------
diff --git a/src/main/config/checkstyle/suppressions.xml b/src/main/config/checkstyle/suppressions.xml
index 18cfabe..c33229c 100644
--- a/src/main/config/checkstyle/suppressions.xml
+++ b/src/main/config/checkstyle/suppressions.xml
@@ -43,6 +43,9 @@ limitations under the License.
   <!-- Suppress JavadocPackage in the test packages -->
   <suppress checks="JavadocPackage" files="src[/\\]test[/\\]java[/\\]"/>
 
+  <!-- And likewise in ubenchmark -->
+  <suppress checks="JavadocPackage" files="StatementTest.java"/>
+
   <!-- Method names in Resource can have underscores -->
   <suppress checks="MethodName" files="EigenbaseNewResource.java"/>
 

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/ubenchmark/src/main/java/net/hydromatic/optiq/StatementTest.java
----------------------------------------------------------------------
diff --git a/ubenchmark/src/main/java/net/hydromatic/optiq/StatementTest.java b/ubenchmark/src/main/java/net/hydromatic/optiq/StatementTest.java
index 67a9d60..29080dc 100644
--- a/ubenchmark/src/main/java/net/hydromatic/optiq/StatementTest.java
+++ b/ubenchmark/src/main/java/net/hydromatic/optiq/StatementTest.java
@@ -26,6 +26,22 @@ import java.util.*;
 
 /**
  * Compares {@link java.sql.Statement} vs {@link java.sql.PreparedStatement}.
+ *
+ * <p>This package contains micro-benchmarks to test optiq performance.
+ *
+ * <p>To run this and other benchmarks:
+ *
+ * <blockquote>
+ *   <code>mvn package &amp;&amp;
+ *   java -jar ./target/ubenchmarks.jar -wi 5 -i 5 -f 1</code>
+ * </blockquote>
+ *
+ * <p>To run with profiling:
+ *
+ * <blockquote>
+ *   <code>java -Djmh.stack.lines=10 -jar ./target/ubenchmarks.jar
+ *     -prof hs_comp,hs_gc,stack -f 1 -wi 5</code>
+ * </blockquote>
  */
 public class StatementTest {
 

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/55fbf047/ubenchmark/src/main/java/net/hydromatic/optiq/package-info.java
----------------------------------------------------------------------
diff --git a/ubenchmark/src/main/java/net/hydromatic/optiq/package-info.java b/ubenchmark/src/main/java/net/hydromatic/optiq/package-info.java
deleted file mode 100644
index a24acca..0000000
--- a/ubenchmark/src/main/java/net/hydromatic/optiq/package-info.java
+++ /dev/null
@@ -1,25 +0,0 @@
-/*
-// Licensed to the Apache Software Foundation (ASF) under one or more
-// contributor license agreements.  See the NOTICE file distributed with
-// this work for additional information regarding copyright ownership.
-// The ASF licenses this file to you under the Apache License, Version 2.0
-// (the "License"); you may not use this file except in compliance with
-// the License.  You may obtain a copy of the License at
-//
-// http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-*/
-/**
- * Microbenchmarks to test optiq performance.
- * The way to run is
- * {@code mvn package && java -jar ./target/ubenchmarks.jar -wi 5 -i 5 -f 1}.
- * <p>
- * To run with profiling, use {@code java -Djmh.stack.lines=10 -jar
- * ./target/ubenchmarks.jar -prof hs_comp,hs_gc,stack -f 1 -wi 5}.
- */
-package net.hydromatic.optiq;


[8/8] git commit: Disable test that is inconistent between JDK 1.7 and 1.8.

Posted by jh...@apache.org.
Disable test that is inconistent between JDK 1.7 and 1.8.


Project: http://git-wip-us.apache.org/repos/asf/incubator-optiq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-optiq/commit/c4b0c7b3
Tree: http://git-wip-us.apache.org/repos/asf/incubator-optiq/tree/c4b0c7b3
Diff: http://git-wip-us.apache.org/repos/asf/incubator-optiq/diff/c4b0c7b3

Branch: refs/heads/master
Commit: c4b0c7b3d3f870f2bc118a73deb0f31d312a076f
Parents: bb3e55c
Author: Julian Hyde <jh...@apache.org>
Authored: Fri Aug 22 01:37:50 2014 -0700
Committer: Julian Hyde <jh...@apache.org>
Committed: Fri Aug 22 01:37:50 2014 -0700

----------------------------------------------------------------------
 .../net/hydromatic/optiq/test/JdbcFrontJdbcBackLinqMiddleTest.java  | 1 +
 1 file changed, 1 insertion(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/c4b0c7b3/core/src/test/java/net/hydromatic/optiq/test/JdbcFrontJdbcBackLinqMiddleTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/net/hydromatic/optiq/test/JdbcFrontJdbcBackLinqMiddleTest.java b/core/src/test/java/net/hydromatic/optiq/test/JdbcFrontJdbcBackLinqMiddleTest.java
index 577b7ab..41b1945 100644
--- a/core/src/test/java/net/hydromatic/optiq/test/JdbcFrontJdbcBackLinqMiddleTest.java
+++ b/core/src/test/java/net/hydromatic/optiq/test/JdbcFrontJdbcBackLinqMiddleTest.java
@@ -119,6 +119,7 @@ public class JdbcFrontJdbcBackLinqMiddleTest {
    * <p>Currently, the query can be planned, but the plan is not efficient (uses
    * cartesian product).</p>
    */
+  @Ignore("non-deterministic on JDK 1.7 vs 1.8")
   @Test public void testJoinTheta() {
     that()
         .with(OptiqAssert.Config.FOODMART_CLONE)
diff --git a/core/src/main/java/org/eigenbase/rel/rules/RemoveTrivialProjectRule.java b/core/src/main/java/org/eigenbase/rel/rules/RemoveTrivialProjectRule.java
index 630b343..d850351 100644
--- a/core/src/main/java/org/eigenbase/rel/rules/RemoveTrivialProjectRule.java
+++ b/core/src/main/java/org/eigenbase/rel/rules/RemoveTrivialProjectRule.java
@@ -24,7 +24,7 @@ import org.eigenbase.reltype.*;
 import org.eigenbase.rex.*;
 
 /**
  * Rule which, given a {@link ProjectRel} node which merely returns its input,
  * converts the node into its child.
  *
  * <p>For example, <code>ProjectRel(ArrayReader(a), {$input0})</code> becomes
@@ -44,10 +44,10 @@ public class RemoveTrivialProjectRule extends RelOptRule {
     // Create a specialized operand to detect non-matches early. This keeps
     // the rule queue short.
     super(
-      new RelOptRuleOperand(ProjectRel.class, null, any()) {
+      new RelOptRuleOperand(ProjectRelBase.class, null, any()) {
         @Override public boolean matches(RelNode rel) {
           return super.matches(rel)
-              && isTrivial((ProjectRel) rel);
+              && isTrivial((ProjectRelBase) rel);
         }
       });
   }
@@ -55,7 +55,7 @@ public class RemoveTrivialProjectRule extends RelOptRule {
   //~ Methods ----------------------------------------------------------------
 
   public void onMatch(RelOptRuleCall call) {
-    ProjectRel project = call.rel(0);
+    ProjectRelBase project = call.rel(0);
     assert isTrivial(project);
     RelNode stripped = project.getChild();
     RelNode child = call.getPlanner().register(stripped, project);

http://git-wip-us.apache.org/repos/asf/incubator-optiq/blob/48bcaddc/core/src/main/java/org/eigenbase/relopt/RelOptUtil.java
----------------------------------------------------------------------
@@ -24,7 +24,7 @@ import org.eigenbase.reltype.*;
 
 /**
- * Rule which, given a {@link ProjectRel} node which merely returns its input,
+ * Rule which, given a {@link ProjectRelBase} node which merely returns its input,
  * converts the node into its child.
  *